==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/e0/e079cf63cff91a957d97acdde35b626e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-fixed/assets/logo_demo-company-iv.svg */
class __TwigTemplate_992f6923b5a7fd1136bc3461615460ad extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 346.7 52.5\" style=\"enable-background:new 0 0 346.7 52.5;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#FFB600;}
\t.st1{fill:#E5A400;}
</style>
<g>
\t<path class=\"st0\" d=\"M56.6,0v5.7l1.9-0.1l3.9-0.2v0.1c-0.9,1.1-2,3.3-3.1,6.8l-5.7,15.6L50,38.1H50c-1-2.6-1.7-4.3-2-5.1
\t\tc-0.9-2.3-1.6-4.1-2.2-5.5l-6.8-16.8c-0.4-0.9-0.6-1.8-0.6-2.6c0-2.2,1.6-3.2,4.9-3.1V0H21.4h-0.1H0v5.7l5.6-0.2
\t\tc-0.2,1.7-0.3,3.9-0.3,6.7v28.5c0,1.9-0.2,3.3-0.6,4.2c-0.4,0.9-0.9,1.5-1.6,1.7C2.4,47,1.3,47.1,0,47.2v4.9h21.4v-5.7
\t\tc-2.1,0-4,0.1-5.6,0.2c0.2-1.7,0.3-3.9,0.3-6.7V11.4c0-1.9,0.2-3.3,0.6-4.2c0.4-0.9,0.9-1.5,1.6-1.7C19,5.1,20,5,21.2,4.9l4,0.6
\t\tc0,1.4,0.7,3.8,2.1,7.1l17.1,40h6.1l14.9-39.7c1-2.8,2.2-4.8,3.4-6c1.2-1.2,2.7-1.9,4.5-2V0H56.6z\"/>
\t<g>
\t\t<path class=\"st1\" d=\"M113.9,37.6c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3v0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0c-0.7-0.7-1.8-0.9-2.6-0.3
\t\t\tC116,36.4,114.8,37.2,113.9,37.6z\"/>
\t\t<path class=\"st1\" d=\"M152,11.9c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C156.6,15.3,154.6,13.3,152,11.9z M154.2,32.5c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC155.9,28.5,155.3,30.6,154.2,32.5z\"/>
\t\t<path class=\"st1\" d=\"M186.7,32.8l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.5l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.3c0-1.8-1.5-3.3-3.3-3.3l0,0c-1.2,0-2.4,0.7-2.9,1.8L186.7,32.8z\"/>
\t\t<path class=\"st1\" d=\"M236.7,12.9c-2.2-1.9-5.4-2.9-9.4-2.9H217c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C240,17.5,238.9,14.8,236.7,12.9z M233.5,26.5
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V14.1l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C235.8,23.5,235,25.3,233.5,26.5z\"/>
\t\t<path class=\"st1\" d=\"M255.7,12.1l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3l0,0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C257.5,10,256.2,10.8,255.7,12.1z
\t\t\t M253,28.4l5.8-13.6l5.9,13.6H253z\"/>
\t\t<path class=\"st1\" d=\"M306.2,35.2l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7h-0.2c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.3l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12.2c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35.2z\"/>
\t\t<path class=\"st1\" d=\"M342.9,11l-9.3,16.6L324.2,11c-0.4-0.6-1-1-1.7-1h0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6v7.7c0,1.2,1,2.2,2.2,2.2
\t\t\tl0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C343.9,10,343.3,10.4,342.9,11z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-fixed/assets/logo_demo-company-iv.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-fixed/assets/logo_demo-company-iv.svg", "/var/www/mautic-ktn/themes/fresh-fixed/assets/logo_demo-company-iv.svg");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/e0/e079cf63cff91a957d97acdde35b626e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-fixed/assets/logo_demo-company-iv.svg */
class __TwigTemplate_992f6923b5a7fd1136bc3461615460ad extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 346.7 52.5\" style=\"enable-background:new 0 0 346.7 52.5;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#FFB600;}
\t.st1{fill:#E5A400;}
</style>
<g>
\t<path class=\"st0\" d=\"M56.6,0v5.7l1.9-0.1l3.9-0.2v0.1c-0.9,1.1-2,3.3-3.1,6.8l-5.7,15.6L50,38.1H50c-1-2.6-1.7-4.3-2-5.1
\t\tc-0.9-2.3-1.6-4.1-2.2-5.5l-6.8-16.8c-0.4-0.9-0.6-1.8-0.6-2.6c0-2.2,1.6-3.2,4.9-3.1V0H21.4h-0.1H0v5.7l5.6-0.2
\t\tc-0.2,1.7-0.3,3.9-0.3,6.7v28.5c0,1.9-0.2,3.3-0.6,4.2c-0.4,0.9-0.9,1.5-1.6,1.7C2.4,47,1.3,47.1,0,47.2v4.9h21.4v-5.7
\t\tc-2.1,0-4,0.1-5.6,0.2c0.2-1.7,0.3-3.9,0.3-6.7V11.4c0-1.9,0.2-3.3,0.6-4.2c0.4-0.9,0.9-1.5,1.6-1.7C19,5.1,20,5,21.2,4.9l4,0.6
\t\tc0,1.4,0.7,3.8,2.1,7.1l17.1,40h6.1l14.9-39.7c1-2.8,2.2-4.8,3.4-6c1.2-1.2,2.7-1.9,4.5-2V0H56.6z\"/>
\t<g>
\t\t<path class=\"st1\" d=\"M113.9,37.6c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3v0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0c-0.7-0.7-1.8-0.9-2.6-0.3
\t\t\tC116,36.4,114.8,37.2,113.9,37.6z\"/>
\t\t<path class=\"st1\" d=\"M152,11.9c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C156.6,15.3,154.6,13.3,152,11.9z M154.2,32.5c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC155.9,28.5,155.3,30.6,154.2,32.5z\"/>
\t\t<path class=\"st1\" d=\"M186.7,32.8l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.5l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.3c0-1.8-1.5-3.3-3.3-3.3l0,0c-1.2,0-2.4,0.7-2.9,1.8L186.7,32.8z\"/>
\t\t<path class=\"st1\" d=\"M236.7,12.9c-2.2-1.9-5.4-2.9-9.4-2.9H217c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C240,17.5,238.9,14.8,236.7,12.9z M233.5,26.5
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V14.1l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C235.8,23.5,235,25.3,233.5,26.5z\"/>
\t\t<path class=\"st1\" d=\"M255.7,12.1l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3l0,0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C257.5,10,256.2,10.8,255.7,12.1z
\t\t\t M253,28.4l5.8-13.6l5.9,13.6H253z\"/>
\t\t<path class=\"st1\" d=\"M306.2,35.2l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7h-0.2c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.3l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12.2c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35.2z\"/>
\t\t<path class=\"st1\" d=\"M342.9,11l-9.3,16.6L324.2,11c-0.4-0.6-1-1-1.7-1h0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6v7.7c0,1.2,1,2.2,2.2,2.2
\t\t\tl0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C343.9,10,343.3,10.4,342.9,11z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-fixed/assets/logo_demo-company-iv.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-fixed/assets/logo_demo-company-iv.svg", "/var/www/html/mauticGIT-Test/themes/fresh-fixed/assets/logo_demo-company-iv.svg");
    }
}
